@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 
 """
 Contains some types that are useful in the Mitosheet package. 
@@ -11,14 +12,26 @@ explicit and clear, and make sure to test the types in our
 continous integration
 """
 
-from typing import List, Union, Tuple
+from typing import TYPE_CHECKING, Dict, List, Optional, Union, Tuple, Any
 
+GraphID = str
 ColumnID = str
 
 # A column header is either a primative type
-PrimativeColumnHeader = Union[int, float, bool, str]
+PrimativeColumnHeader = Union[int, float, bool, str, Optional[str]]
 MultiLevelColumnHeader = Union[Tuple[PrimativeColumnHeader, ...], List[PrimativeColumnHeader]]
 # To a tuple of primative types (TODO: does this nest further?).
 ColumnHeader = Union[PrimativeColumnHeader, MultiLevelColumnHeader]
 
+# To resolve circular dependencies, we create a StepsManagerType here
+if TYPE_CHECKING:
+    from mitosheet.steps_manager import StepsManager
+    StepsManagerType = StepsManager
+else:
+    StepsManagerType = Any
+
+
+DataframeFormat = Dict[str, Any]
+ColumnFormat = Dict[str, Any]
+
 
